==> haskell-configurator-0.3.0.0-47-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-JxJ41jyKzAPKY2HSG8zdEM
key: configurator-0.3.0.0-JxJ41jyKzAPKY2HSG8zdEM
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
abi: 10e9f7b9d101ec0c78844c14e827e499
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-JxJ41jyKzAPKY2HSG8zdEM
depends:
    attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ base-4.11.1.0
    bytestring-0.10.8.2 directory-1.3.1.5
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg text-1.2.3.0
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: attoparsec-0.13.2.2-3qGxeNYxa6yc3jTIgvDuQ=d12eb845c076ee59608410c1ed86a159
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-configurator-0.3.0.0-48-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-configurator.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: configurator
version: 0.3.0.0
id: configurator-0.3.0.0-CSPHM6xTnTdL2hGq1jYUDI
key: configurator-0.3.0.0-CSPHM6xTnTdL2hGq1jYUDI
license: BSD-3-Clause
copyright: Copyright 2011 MailRank, Inc.
           Copyright 2011-2014 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
stability: experimental
homepage: http://github.com/bos/configurator
synopsis: Configuration management
description:
    A configuration management library for programs and daemons.
    .
    Features include:
    .
    * Automatic, dynamic reloading in response to modifications to
    configuration files.
    .
    * A simple, but flexible, configuration language, supporting several
    of the most commonly needed types of data, along with
    interpolation of strings from the configuration or the system
    environment (e.g. @$(HOME)@).
    .
    * Subscription-based notification of changes to configuration
    properties.
    .
    * An @import@ directive allows the configuration of a complex
    application to be split across several smaller files, or common
    configuration data to be shared across several applications.
    .
    For details of the configuration file format, see
    <http://hackage.haskell.org/packages/archive/configurator/latest/doc/html/Data-Configurator.html>.
category: Configuration, Data
abi: c6860cb1ecf9300514fd632792e2deca
exposed: True
exposed-modules:
    Data.Configurator Data.Configurator.Types
hidden-modules: Data.Configurator.Instances
                Data.Configurator.Parser Data.Configurator.Types.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/configurator-0.3.0.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/configurator-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/haskell-configurator
hs-libraries: HSconfigurator-0.3.0.0-CSPHM6xTnTdL2hGq1jYUDI
depends:
    attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ base-4.11.1.0
    bytestring-0.10.8.2 directory-1.3.1.5
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg text-1.2.3.0
    unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y
    unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y
abi-depends: attoparsec-0.13.2.2-KQfUWPhYfGY7y53JEXSJuZ=5fc61cc528c94bde8145f6cbd8ed3b00
             base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=ad8d36b5596969152937469512f0d3b1
             text-1.2.3.0=be4c3e1c57cff1d501eb0e876706a48d
             unix-compat-0.5.0.1-EHbnKrAgBdbLiFhZ6tM1y=363ae7a014dbeccc58dc4736b1be85cd
             unordered-containers-0.2.9.0-4xkK4TVeOzU5CT7vUnH40Y=35805d13add6a65c87fb8fb413d93b58
haddock-interfaces: /usr/share/doc/haskell-configurator/html/configurator.haddock
haddock-html: /usr/share/doc/haskell-configurator/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
